<!-- markdownlint-disable -->
<!-- prettier-ignore-start -->
> [!IMPORTANT]
> On June 26 2024, Linux Foundation announced the merger of its financial services umbrella, the Fintech Open Source Foundation ([FINOS](https://finos.org)), with OS-Climate, an open source community dedicated to building data technologies, modeling, and analytic tools that will drive global capital flows into climate change mitigation and resilience; OS-Climate projects are in the process of transitioning to the [FINOS governance framework](https://community.finos.org/docs/governance); read more on [finos.org/press/finos-join-forces-os-open-source-climate-sustainability-esg](https://finos.org/press/finos-join-forces-os-open-source-climate-sustainability-esg)
<!-- prettier-ignore-end -->
<!-- markdownlint-enable -->

# osc-physrisk-financial

Physical climate risk financial valuation

<img src="docs/images/OS-Climate-Logo.png" alt="drawing" width="150"/>

## About osc-physrisk-financial

An [OS-Climate](https://os-climate.org) project, osc-physrisk-financial
is a library for valuating assets under different climate risk scenarios.

## Using the library

The library can be run locally and is installed via:

```shell
pip install osc-physrisk-financial
```

The library uses the output generated by the
[physrisk](https://github.com/os-climate/physrisk) library

### Note

This is the first stage of development, where the models are intentionally
simple, focusing on setting up the proper structure of the library.
